@@ -47,13 +47,15 @@
 #include "Splash.h"
 #include "TopWidget.h"
 
+using namespace Qt::StringLiterals;
+
 /** maximum number of recent files */
 #define MAX_RECENT_FILES 20
 
 //***************************************************************************
 Kwave::App::App(int &argc, char **argv)
    :QApplication(argc, argv),
-    m_cmdline(Q_NULLPTR),
+    m_cmdline(nullptr),
     m_recent_files(),
     m_top_widgets(),
     m_gui_type(Kwave::App::GUI_TAB)
@@ -81,7 +83,7 @@ void Kwave::App::processCmdline(QCommandLineParser *cmdline)
 
     // read the configured user interface type
     QString result;
-    KConfigGroup cfg = KSharedConfig::openConfig()->group("Global");
+    KConfigGroup cfg = KSharedConfig::openConfig()->group(u"Global"_s);
     result = cfg.readEntry("UI Type");
     if (result == _("SDI")) {
         m_gui_type = Kwave::App::GUI_SDI;
@@ -223,7 +225,7 @@ void Kwave::App::addRecentFile(const QString &newfile)
 int Kwave::App::newWindow(const QUrl &url)
 {
     int retval = 0;
-    Kwave::TopWidget *new_top_widget = Q_NULLPTR;
+    Kwave::TopWidget *new_top_widget = nullptr;
 
     Kwave::Splash::showMessage(i18n("Opening main window..."));
 
@@ -240,6 +242,7 @@ int Kwave::App::newWindow(const QUrl &url)
                  !m_top_widgets.isEmpty() )
                 new_top_widget = m_top_widgets.last();
             break;
+        DEFAULT_IMPOSSIBLE;
     }
 
     if (!new_top_widget) {
@@ -332,7 +335,7 @@ void Kwave::App::switchGuiType(Kwave::TopWidget *top, GuiType new_type)
     if (!all_contexts.isEmpty()) {
         bool first = true;
         foreach (Kwave::FileContext *context, all_contexts) {
-            Kwave::TopWidget *top_widget = Q_NULLPTR;
+            Kwave::TopWidget *top_widget = nullptr;
 
             switch (m_gui_type) {
                 case GUI_SDI:
@@ -380,20 +383,21 @@ void Kwave::App::switchGuiType(Kwave::TopWidget *top, GuiType new_type)
                     // all contexts go into the same toplevel widget
                     top_widget = top;
                     break;
+                DEFAULT_IMPOSSIBLE;
             }
 
             if (top_widget) top_widget->insertContext(context);
         }
     } else {
         // give our one and only toplevel widget a default context
-        top->insertContext(Q_NULLPTR);
+        top->insertContext(nullptr);
     }
 }
 
 //***************************************************************************
 void Kwave::App::saveRecentFiles()
 {
-    KConfigGroup cfg = KSharedConfig::openConfig()->group("Recent Files");
+    KConfigGroup cfg = KSharedConfig::openConfig()->group(u"Recent Files"_s);
 
     QString num;
     for (int i = 0 ; i < MAX_RECENT_FILES; i++) {
@@ -410,7 +414,7 @@ void Kwave::App::saveRecentFiles()
 //***************************************************************************
 void Kwave::App::readConfig()
 {
-    const KConfigGroup cfg = KSharedConfig::openConfig()->group("Recent Files");
+    const KConfigGroup cfg = KSharedConfig::openConfig()->group(u"Recent Files"_s);
 
     for (unsigned int i = 0 ; i < MAX_RECENT_FILES; i++) {
         QString key = QString::number(i);        // generate number
@@ -429,3 +433,5 @@ void Kwave::App::readConfig()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_App.cpp"
