@@ -19,6 +19,7 @@
 
 #include <QKeySequence>
 #include <QObject>
+#include <QWidget>
 
 #include "ShortcutWrapper.h"
 
@@ -45,3 +46,5 @@ void Kwave::ShortcutWrapper::triggered()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_ShortcutWrapper.cpp"
