@@ -19,6 +19,7 @@
 #define IMAGEVIEW_H
 
 #include "config.h"
+#include "libkwavegui_export.h"
 
 #include <QtGlobal>
 #include <QImage>
@@ -30,7 +31,7 @@ namespace Kwave
     /**
      * Simple widget class for displaying a QImage.
      */
-    class Q_DECL_EXPORT ImageView: public QWidget
+    class LIBKWAVEGUI_EXPORT ImageView: public QWidget
     {
         Q_OBJECT
     public:
@@ -44,14 +45,14 @@ namespace Kwave
          *        vertically into the widget; if false the image will be
          *        cut off at the edge and should be scrolled
          */
-        explicit ImageView(QWidget *parent = Q_NULLPTR,
+        explicit ImageView(QWidget *parent = nullptr,
                            bool fit_width  = true,
                            bool fit_height = true);
 
         /**
          * Destructor
          */
-        virtual ~ImageView() Q_DECL_OVERRIDE;
+        ~ImageView() override;
 
         /**
          * Returns the position and size of the current image, packed
@@ -81,11 +82,11 @@ namespace Kwave
 
     protected:
 
-        virtual void mouseMoveEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+        void mouseMoveEvent(QMouseEvent *e) override;
 
-        virtual void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+        void mousePressEvent(QMouseEvent *e) override;
 
-        virtual void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+        void paintEvent(QPaintEvent *) override;
 
     private:
         /**
