@@ -19,6 +19,7 @@
 #define LABEL_ITEM_H
 
 #include "config.h"
+#include "libkwavegui_export.h"
 
 #include <QtGlobal>
 #include <QCursor>
@@ -36,7 +37,7 @@ namespace Kwave
     class SignalView;
     class UndoTransactionGuard;
 
-    class Q_DECL_EXPORT LabelItem: public Kwave::ViewItem
+    class LIBKWAVEGUI_EXPORT LabelItem: public Kwave::ViewItem
     {
         Q_OBJECT
     public:
@@ -53,13 +54,13 @@ namespace Kwave
                   const Kwave::Label &label);
 
         /** Destructor */
-        virtual ~LabelItem() Q_DECL_OVERRIDE;
+        ~LabelItem() override;
 
         /**
          * Returns flags describing the possible interactions with this object
          * @see Kwave::ViewItem::Flags
          */
-        virtual Kwave::ViewItem::Flags flags() const Q_DECL_OVERRIDE;
+        Kwave::ViewItem::Flags flags() const override;
 
         /**
          * Can be overwritten to return a tooltip.
@@ -67,31 +68,31 @@ namespace Kwave
          * @param ofs sample index the tooltip should refer to (unused)
          * @return an already localized tooltip
          */
-        virtual QString toolTip(sample_index_t &ofs) Q_DECL_OVERRIDE;
+        QString toolTip(sample_index_t &ofs) override;
 
         /**
          * Called to append entries to a context menu.
          * @param parent context menu to add items
          */
-        virtual void appendContextMenu(QMenu *parent) Q_DECL_OVERRIDE;
+        void appendContextMenu(QMenu *parent) override;
 
         /**
          * Returns a mouse cursor used when moving the item
          */
-        virtual QCursor mouseCursor() const Q_DECL_OVERRIDE;
+        QCursor mouseCursor() const override;
 
         /**
          * handles updates when being moved with the mouse
          * @param mouse_pos position of the mouse, in pixel coordinates
          *                  relative to the parent widget
          */
-        virtual void moveTo(const QPoint &mouse_pos) Q_DECL_OVERRIDE;
+        void moveTo(const QPoint &mouse_pos) override;
 
         /**
          * Called when leaving the move mode, when the mouse button
          * has been released.
          */
-        virtual void done() Q_DECL_OVERRIDE;
+        void done() override;
 
     private slots:
 
