@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <math.h>
 
@@ -32,8 +31,10 @@
 #include "libgui/LabelPropertiesWidget.h"
 #include "libgui/SelectTimeWidget.h"
 
+using namespace Qt::StringLiterals;
+
 /** name of the section in the config file */
-#define CONFIG_SECTION "LabelProperties"
+#define CONFIG_SECTION u"LabelProperties"_s
 
 //***************************************************************************
 Kwave::LabelPropertiesWidget::LabelPropertiesWidget(QWidget *parent)
@@ -132,3 +133,5 @@ void Kwave::LabelPropertiesWidget::saveSettings()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_LabelPropertiesWidget.cpp"
