@@ -19,6 +19,7 @@
 #define SELECTION_TRACKER_H
 
 #include "config.h"
+#include "libkwavegui_export.h"
 
 #include <QtGlobal>
 #include <QList>
@@ -39,7 +40,7 @@ namespace Kwave
     class Track;
     class UndoTransaction;
 
-    class Q_DECL_EXPORT SelectionTracker: public QObject,
+    class LIBKWAVEGUI_EXPORT SelectionTracker: public QObject,
                                           private Kwave::UndoHandler
     {
         Q_OBJECT
@@ -57,7 +58,7 @@ namespace Kwave
                          const QVector<unsigned int> *tracks);
 
         /** Destructor */
-        virtual ~SelectionTracker() Q_DECL_OVERRIDE;
+        ~SelectionTracker() override;
 
         /**
          * Returns all currently selected tracks
@@ -201,14 +202,14 @@ namespace Kwave
          * @retval false if saving undo data failed, e.g. out of memory
          *               or aborted
          */
-        virtual bool saveUndoData(Kwave::UndoTransaction &undo) Q_DECL_OVERRIDE;
+        bool saveUndoData(Kwave::UndoTransaction &undo) override;
 
     private:
 
         /**
          * Undo action for tracking selection changes
          */
-        class Q_DECL_EXPORT Undo: public Kwave::UndoAction
+        class LIBKWAVEGUI_EXPORT Undo: public Kwave::UndoAction
         {
         public:
 
@@ -219,12 +220,12 @@ namespace Kwave
             explicit Undo(Kwave::SelectionTracker *selection);
 
             /** Destructor */
-            virtual ~Undo() Q_DECL_OVERRIDE;
+            ~Undo() override;
 
             /**
              * Returns a verbose short description of the action.
              */
-            virtual QString description() Q_DECL_OVERRIDE;
+            QString description() override;
 
             /**
              * Returns the required amount of memory that is needed for storing
@@ -232,13 +233,13 @@ namespace Kwave
              * free memory to be reserved.
              * @note this is the first step (after the constructor)
              */
-            virtual qint64 undoSize() Q_DECL_OVERRIDE;
+            qint64 undoSize() override;
 
             /**
              * Returns the difference of needed memory that is needed for
              * redo.
              */
-            virtual qint64 redoSize() Q_DECL_OVERRIDE;
+            qint64 redoSize() override;
 
             /**
              * Stores the data needed for undo.
@@ -246,7 +247,7 @@ namespace Kwave
              * @note this is the second step, after size() has been called
              * @return true if successful, false if failed (e.g. out of memory)
              */
-            virtual bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
+            bool store(Kwave::SignalManager &manager) override;
 
             /**
              * Takes back an action by creating a new undo action (for further
@@ -258,20 +259,20 @@ namespace Kwave
              *       undo/redo. You have to check for this when deleting an
              *       UndoAction object after undo.
              */
-            virtual Kwave::UndoAction *undo(Kwave::SignalManager &manager,
-                                            bool with_redo) Q_DECL_OVERRIDE;
+            Kwave::UndoAction *undo(Kwave::SignalManager &manager,
+                                            bool with_redo) override;
 
             /**
              * This undo action does not contribute to the modification
              * of the signal.
              * @return true always
              */
-            virtual bool containsModification() const Q_DECL_OVERRIDE {
+            bool containsModification() const override {
                 return false;
             }
 
             /** dump, for debugging purposes */
-            virtual void dump(const QString &indent) Q_DECL_OVERRIDE {
+            void dump(const QString &indent) override {
                 qDebug("%s%s", DBG(indent), DBG(description()));
             }
 
