@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <math.h>
 #include <new>
@@ -41,9 +40,7 @@
 #include "libkwave/Utils.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
 
-#include "libgui/MouseMark.h"
 #include "libgui/SignalView.h"
-#include "libgui/ViewItem.h"
 
 /** number of milliseconds until the position widget disappears */
 #define POSITION_WIDGET_TIME 5000
@@ -68,7 +65,7 @@ Kwave::SignalView::SignalView(QWidget *parent, QWidget *controls,
      m_position_widget(this),
      m_position_widget_timer(this),
      m_siblings(),
-     m_selected_item(Q_NULLPTR)
+     m_selected_item(nullptr)
 {
     // connect the timer of the position widget
     connect(&m_position_widget_timer, SIGNAL(timeout()),
@@ -93,7 +90,7 @@ Kwave::SignalView::~SignalView()
         while (it.hasPrevious()) {
             QWidget *widget = it.previous();
             it.remove();
-            if (widget) delete widget;
+            delete widget;
         }
     }
 }
@@ -218,7 +215,7 @@ bool Kwave::SignalView::isInSelection(int x)
 QSharedPointer<Kwave::ViewItem> Kwave::SignalView::findItem(const QPoint &pos)
 {
     Q_UNUSED(pos)
-    return QSharedPointer<Kwave::ViewItem>(Q_NULLPTR);
+    return QSharedPointer<Kwave::ViewItem>(nullptr);
 }
 
 //***************************************************************************
@@ -289,7 +286,7 @@ void Kwave::SignalView::showPosition(const QString &text, sample_index_t pos,
 //***************************************************************************
 void Kwave::SignalView::findNewItem(const QPoint &mouse_pos, bool active)
 {
-    m_selected_item = QSharedPointer<Kwave::ViewItem>(Q_NULLPTR);
+    m_selected_item = QSharedPointer<Kwave::ViewItem>(nullptr);
     if (!active) m_mouse_mode = MouseNormal;
 
     m_selected_item = findItem(mouse_pos);
@@ -334,8 +331,8 @@ void Kwave::SignalView::mouseMoveEvent(QMouseEvent *e)
     // coordinates on the start of a fast move!?
     // globalPos() seems not to have this effect
     const QPoint mouse_pos(
-        qBound(0, mapFromGlobal(e->globalPos()).x(), width()  - 1),
-        qBound(0, mapFromGlobal(e->globalPos()).y(), height() - 1)
+        qBound(0, mapFromGlobal(e->globalPosition().toPoint()).x(), width()  - 1),
+        qBound(0, mapFromGlobal(e->globalPosition().toPoint()).y(), height() - 1)
     );
 
     // bail out if the position did not change
@@ -410,8 +407,8 @@ void Kwave::SignalView::mousePressEvent(QMouseEvent *e)
     }
 
     const QPoint mouse_pos(
-        qBound(0, mapFromGlobal(e->globalPos()).x(), width()  - 1),
-        qBound(0, mapFromGlobal(e->globalPos()).y(), height() - 1)
+        qBound(0, mapFromGlobal(e->globalPosition().toPoint()).x(), width()  - 1),
+        qBound(0, mapFromGlobal(e->globalPosition().toPoint()).y(), height() - 1)
     );
 
     findNewItem(mouse_pos, false);
@@ -484,8 +481,8 @@ void Kwave::SignalView::mouseReleaseEvent(QMouseEvent *e)
     }
 
     const QPoint mouse_pos(
-        qBound(0, mapFromGlobal(e->globalPos()).x(), width()  - 1),
-        qBound(0, mapFromGlobal(e->globalPos()).y(), height() - 1)
+        qBound(0, mapFromGlobal(e->globalPosition().toPoint()).x(), width()  - 1),
+        qBound(0, mapFromGlobal(e->globalPosition().toPoint()).y(), height() - 1)
     );
 
     switch (m_mouse_mode) {
@@ -534,7 +531,7 @@ void Kwave::SignalView::keyPressEvent(QKeyEvent *e)
         // Cancel key (Escape) -> reset all view item operations
         m_mouse_mode = MouseNormal;
         setCursor(Qt::ArrowCursor);
-        m_selected_item = QSharedPointer<Kwave::ViewItem>(Q_NULLPTR);
+        m_selected_item = QSharedPointer<Kwave::ViewItem>(nullptr);
     } else {
         QWidget::keyPressEvent(e);
     }
@@ -588,7 +585,7 @@ void Kwave::SignalView::dropEvent(QDropEvent *event)
     if (Kwave::Drag::canDecode(mime_data)) {
         Kwave::UndoTransactionGuard undo(*m_signal_manager,
                                          i18n("Drag and Drop"));
-        sample_index_t pos = m_offset + pixels2samples(event->pos().x());
+        sample_index_t pos = m_offset + pixels2samples(event->position().toPoint().x());
         sample_index_t len = 0;
 
         if ((len = Kwave::Drag::decode(this, mime_data,
@@ -637,7 +634,7 @@ void Kwave::SignalView::dropEvent(QDropEvent *event)
 void Kwave::SignalView::dragMoveEvent(QDragMoveEvent *event)
 {
     if (!event) return;
-    const int x = event->pos().x();
+    const int x = event->position().toPoint().x();
 
     if ((event->source() == this) && isInSelection(x)) {
         // disable drag&drop into the selection itself
@@ -687,7 +684,7 @@ void Kwave::SignalView::dragMoveEvent(QDragMoveEvent *event)
 //***************************************************************************
 //***************************************************************************
 Kwave::SignalView::PositionWidget::PositionWidget(QWidget *parent)
-    :QWidget(parent), m_label(Q_NULLPTR), m_alignment(),
+    :QWidget(parent), m_label(nullptr), m_alignment(),
      m_radius(10), m_arrow_length(30), m_last_alignment(Qt::AlignHCenter),
      m_last_size(QSize(0,0)), m_polygon()
 {
@@ -713,8 +710,8 @@ Kwave::SignalView::PositionWidget::PositionWidget(QWidget *parent)
 //***************************************************************************
 Kwave::SignalView::PositionWidget::~PositionWidget()
 {
-    if (m_label) delete m_label;
-    m_label = Q_NULLPTR;
+    delete m_label;
+    m_label = nullptr;
 }
 
 //***************************************************************************
@@ -825,3 +822,5 @@ void Kwave::SignalView::PositionWidget::paintEvent(QPaintEvent *)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_SignalView.cpp"
