@@ -19,17 +19,17 @@
 #define CONFIRM_CANCEL_PROXY_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QObject>
 
-class QString;
 class QWidget;
 
 namespace Kwave
 {
 
-    class Q_DECL_EXPORT ConfirmCancelProxy: public QObject
+    class LIBKWAVE_EXPORT ConfirmCancelProxy: public QObject
     {
         Q_OBJECT
     public:
@@ -52,7 +52,7 @@ namespace Kwave
                            QObject *receiver, const char *slot);
 
         /** Destructor */
-        virtual ~ConfirmCancelProxy();
+        ~ConfirmCancelProxy() override;
 
     public slots:
 
