@@ -49,11 +49,11 @@ Kwave::FileProgress::FileProgress(QWidget *parent,
     :QDialog(parent),
      m_url(url),
      m_size(size),
-     m_lbl_url(Q_NULLPTR),
-     m_lbl_length(Q_NULLPTR),
-     m_progress(Q_NULLPTR),
-     m_stat_transfer(Q_NULLPTR),
-     m_stat_bytes(Q_NULLPTR),
+     m_lbl_url(nullptr),
+     m_lbl_length(nullptr),
+     m_progress(nullptr),
+     m_stat_transfer(nullptr),
+     m_stat_bytes(nullptr),
      m_time(),
      m_canceled(true),
      m_last_percent(0),
@@ -232,7 +232,7 @@ void Kwave::FileProgress::fitUrlLabel()
     while (m_lbl_url->sizeHint().width() > width) {
         // delete characters in the middle of the string
         url = m_url.toString();
-        int len = url.length();
+        int len = static_cast<int>(url.length());
         if (len <= todel) break;
         url = url.left((len-todel)/2) + _("...") +
             url.right((len-todel)/2 + 4);
@@ -249,7 +249,7 @@ QLabel *Kwave::FileProgress::addInfoLabel(QGridLayout *layout,
 {
     QLabel *label = new(std::nothrow) QLabel(this);
     Q_ASSERT(label);
-    if (!label) return Q_NULLPTR;
+    if (!label) return nullptr;
 
     label->setText(text);
     label->adjustSize();
@@ -379,3 +379,5 @@ void Kwave::FileProgress::cancel()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_FileProgress.cpp"
