@@ -19,6 +19,7 @@
 #define MULTI_TRACK_SOURCE_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <new>
 
@@ -37,7 +38,7 @@ namespace Kwave
      * that consist of multiple independent tracks.
      */
     template <class SOURCE, const bool INITIALIZE>
-    class Q_DECL_EXPORT MultiTrackSource: public Kwave::SampleSource,
+    class LIBKWAVE_EXPORT MultiTrackSource: public Kwave::SampleSource,
                                           private QList<SOURCE *>
     {
     public:
@@ -60,7 +61,7 @@ namespace Kwave
         }
 
         /** Destructor */
-        virtual ~MultiTrackSource() Q_DECL_OVERRIDE
+        ~MultiTrackSource() override
         {
             clear();
         }
@@ -69,7 +70,7 @@ namespace Kwave
          * Calls goOn() for each track.
          * @see Kwave::SampleSource::goOn()
          */
-        virtual void goOn() Q_DECL_OVERRIDE
+        void goOn() override
         {
             if (isCanceled()) return;
 
@@ -77,8 +78,8 @@ namespace Kwave
             foreach (SOURCE *src, static_cast< QList<SOURCE *> >(*this)) {
                 if (!src) continue;
                 synchronizer.addFuture(QtConcurrent::run(
-                    this,
                     &Kwave::MultiTrackSource<SOURCE, INITIALIZE>::runSource,
+                    this,
                     src)
                 );
             }
@@ -86,7 +87,7 @@ namespace Kwave
         }
 
         /** Returns true when all sources are done */
-        virtual bool done() const Q_DECL_OVERRIDE
+        bool done() const override
         {
             foreach (SOURCE *src, static_cast< QList<SOURCE *> >(*this))
                 if (src && !src->done()) return false;
@@ -97,9 +98,9 @@ namespace Kwave
          * Returns the number of tracks that the source provides
          * @return number of tracks
          */
-        virtual unsigned int tracks() const Q_DECL_OVERRIDE
+        unsigned int tracks() const override
         {
-            return QList<SOURCE *>::size();
+            return static_cast<unsigned int>(QList<SOURCE *>::size());
         }
 
         /**
@@ -113,7 +114,7 @@ namespace Kwave
 
         /** @see the Kwave::MultiTrackSource.at()... */
         inline virtual SOURCE * operator [] (unsigned int track)
-            Q_DECL_OVERRIDE
+            override
         {
             return at(track);
         }
@@ -152,7 +153,7 @@ namespace Kwave
      * by generating them through their default constructor.
      */
     template <class SOURCE>
-    class Q_DECL_EXPORT MultiTrackSource<SOURCE, true>
+    class LIBKWAVE_EXPORT MultiTrackSource<SOURCE, true>
         :public Kwave::MultiTrackSource<SOURCE, false>
     {
     public:
@@ -163,7 +164,7 @@ namespace Kwave
          * @param parent a parent object, passed to QObject (optional)
          */
         MultiTrackSource(unsigned int tracks,
-                         QObject *parent = Q_NULLPTR)
+                         QObject *parent = nullptr)
             :Kwave::MultiTrackSource<SOURCE, false>(0, parent)
         {
             for (unsigned int i = 0; i < tracks; i++)
@@ -171,7 +172,7 @@ namespace Kwave
         }
 
         /** Destructor */
-        virtual ~MultiTrackSource() { }
+        virtual ~MultiTrackSource() override { }
     };
 
 }
