@@ -21,8 +21,8 @@
 #include <new>
 
 #include "libkwave/MultiTrackWriter.h"
-#include "libkwave/SampleArray.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/Utils.h"
 #include "libkwave/undo/UndoInsertAction.h"
 #include "libkwave/undo/UndoModifyAction.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
@@ -120,7 +120,7 @@ bool Kwave::MultiTrackWriter::init(Kwave::SignalManager &signal_manager,
                      Qt::QueuedConnection);
 
     // create an undo action for the modification of the samples
-    UndoAction *undo = Q_NULLPTR;
+    UndoAction *undo = nullptr;
     switch (mode) {
         case Kwave::Append:
         case Kwave::Insert: {
@@ -153,6 +153,7 @@ bool Kwave::MultiTrackWriter::init(Kwave::SignalManager &signal_manager,
             }
             break;
         }
+        DEFAULT_IMPOSSIBLE;
     }
 
     if ( (mode != Kwave::Overwrite) &&
@@ -171,3 +172,5 @@ bool Kwave::MultiTrackWriter::init(Kwave::SignalManager &signal_manager,
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_MultiTrackWriter.cpp"
