@@ -19,6 +19,7 @@
 #define SAMPLE_SOURCE_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QObject>
@@ -28,7 +29,7 @@
 
 namespace Kwave
 {
-    class Q_DECL_EXPORT SampleSource: public Kwave::StreamObject
+    class LIBKWAVE_EXPORT SampleSource: public Kwave::StreamObject
     {
         Q_OBJECT
     public:
@@ -38,10 +39,10 @@ namespace Kwave
          *
          * @param parent a parent object, passed to QObject (optional)
          */
-        explicit SampleSource(QObject *parent = Q_NULLPTR);
+        explicit SampleSource(QObject *parent = nullptr);
 
         /** Destructor */
-        virtual ~SampleSource();
+        ~SampleSource() override;
 
         /**
          * Each KwaveSampleSource has to derive this method for producing
