@@ -19,9 +19,11 @@
 #define TRACK_H
 
 #include "config.h"
+#include "libkwave_export.h"
+
+#include <vector>
 
 #include <QtGlobal>
-#include <QList>
 #include <QObject>
 #include <QReadWriteLock>
 #include <QRecursiveMutex>
@@ -40,7 +42,7 @@ namespace Kwave
     class TrackWriter;
     class Writer;
 
-    class Q_DECL_EXPORT Track: public QObject
+    class LIBKWAVE_EXPORT Track: public QObject
     {
         Q_OBJECT
     public:
@@ -60,7 +62,7 @@ namespace Kwave
         /**
          * Destructor.
          */
-        virtual ~Track();
+        virtual ~Track() override;
 
         /**
          * Returns the length of the track. This is equivalent
@@ -310,7 +312,7 @@ namespace Kwave
         QReadWriteLock m_lock_usage;
 
         /** list of stripes (a track actually is a container for stripes) */
-        QList<Stripe> m_stripes;
+        std::vector<Stripe> m_stripes;
 
         /** True if the track is selected */
         bool m_selected;
