@@ -31,7 +31,6 @@
 
 namespace Kwave
 {
-    class KwaveSampleSource;
 
     class BandPassPlugin: public Kwave::FilterPlugin
     {
@@ -47,11 +46,11 @@ namespace Kwave
         BandPassPlugin(QObject *parent, const QVariantList &args);
 
         /** Destructor */
-        virtual ~BandPassPlugin() Q_DECL_OVERRIDE;
+        ~BandPassPlugin() override;
 
         /** Creates the setup dialog and connects it's signals */
         virtual Kwave::PluginSetupDialog *createDialog(QWidget *parent)
-            Q_DECL_OVERRIDE;
+            override;
 
         /**
          * Creates a multi-track filter with the given number of tracks
@@ -59,12 +58,12 @@ namespace Kwave
          * @return pointer to the filter or null if failed
          */
         virtual Kwave::SampleSource *createFilter(unsigned int tracks)
-            Q_DECL_OVERRIDE;
+            override;
 
         /**
          * Returns true if the parameters have changed during pre-listen.
          */
-        virtual bool paramsChanged() Q_DECL_OVERRIDE;
+        bool paramsChanged() override;
 
         /**
          * Update the filter with new parameters if it has changed
@@ -74,18 +73,18 @@ namespace Kwave
          * @param force if true, even update if no settings have changed
          */
         virtual void updateFilter(Kwave::SampleSource *filter,
-                                  bool force = false) Q_DECL_OVERRIDE;
+                                  bool force = false) override;
 
         /**
          * Returns a verbose name of the performed action. Used for giving
          * the undo action a readable name.
          */
-        virtual QString actionName() Q_DECL_OVERRIDE;
+        QString actionName() override;
 
     protected:
 
         /** Reads values from the parameter list */
-        virtual int interpreteParameters(QStringList &params) Q_DECL_OVERRIDE;
+        int interpreteParameters(QStringList &params) override;
 
     protected slots:
 
