@@ -27,6 +27,7 @@
 #include <id3/misc_support.h>
 #include <id3/tag.h>
 
+#include <QBuffer>
 #include <QDate>
 #include <QDateTime>
 #include <QIODevice>
@@ -44,6 +45,7 @@
 #include "libkwave/Writer.h"
 
 #include "ID3_QIODeviceReader.h"
+#include "ID3_QIODeviceWriter.h"
 #include "MP3CodecPlugin.h"
 #include "MP3Decoder.h"
 
@@ -84,7 +86,7 @@ bool Kwave::MP3Decoder::parseMp3Header(const Mp3_Headerinfo &header,
     Kwave::FileInfo info(metaData());
 
     /* first of all check CRC, it might be senseless if the file is broken */
-    qDebug("crc = 0x%08X", header.crc);
+    qDebug("crc = 0x%08X", static_cast<unsigned int>(header.crc));
     if ((header.crc == MP3CRC_MISMATCH) || (header.crc == MP3CRC_ERROR_SIZE)) {
 
         if (header.layer == MPEGLAYER_II) {
@@ -222,9 +224,10 @@ bool Kwave::MP3Decoder::parseID3Tags(ID3_Tag &tag)
     ID3_Tag::Iterator *it = tag.CreateIterator();
     ID3_Frame *frame = nullptr;
     Kwave::FileInfo info(metaData());
+    QVariantList custom_frames;
     while (it && (frame = it->GetNext())) {
-        const ID3_FrameID id = frame->GetID();
-        const Kwave::FileProperty property = m_property_map.property(id);
+        const ID3_FrameID               id       = frame->GetID();
+        Kwave::FileProperty             property = m_property_map.property(id);
         const ID3_PropertyMap::Encoding encoding = m_property_map.encoding(id);
         switch (encoding) {
             case ID3_PropertyMap::ENC_TEXT_PARTINSET:
@@ -264,6 +267,7 @@ bool Kwave::MP3Decoder::parseID3Tags(ID3_Tag &tag)
                 /* FALLTHROUGH */
             case ID3_PropertyMap::ENC_COMMENT:
             {
+                // list of strings
                 QString s = parseId3Frame2String(frame);
 
                 // optionally prepend language
@@ -273,10 +277,11 @@ bool Kwave::MP3Decoder::parseID3Tags(ID3_Tag &tag)
                     ID3_FreeString(lang);
                 }
 
-                // append to already existing tag, separated by a slash
+                QStringList list;
                 if (info.contains(property))
-                    s = info.get(property).toString() + _(" / ") + s;
-                info.set(property, QVariant(s));
+                    list = info.get(property).toStringList();
+                list.append(s);
+                info.set(property, QVariant(list));
                 break;
             }
             case ID3_PropertyMap::ENC_GENRE_TYPE:
@@ -361,14 +366,26 @@ bool Kwave::MP3Decoder::parseID3Tags(ID3_Tag &tag)
             case ID3_PropertyMap::ENC_NONE: /* FALLTHROUGH */
             default:
             {
-                QString s = parseId3Frame2String(frame);
-                qWarning("unsupported ID3 tag: %d, descr: '%s', text: '%s'",
-                         id, frame->GetDescription(), DBG(s));
+                qWarning("unsupported ID3 frame: %d, descr: '%s'",
+                         id, frame->GetDescription());
+
+                QBuffer buffer;
+                buffer.open(QIODevice::ReadWrite);
+                Kwave::ID3_QIODeviceWriter writer(buffer);
+                frame->Render(writer);
+
+                qDebug("-> storing, buffer size = %lli bytes", buffer.size());
+                custom_frames.append(QVariant(
+                    QString::fromLocal8Bit(buffer.data().toBase64())));
                 break;
             }
         }
     }
 
+    /* add custom (unsupported) ID3 frames 1:1 (just store internally) */
+    if (!custom_frames.isEmpty())
+        info.set(Kwave::INF_ID3, QVariant(custom_frames));
+
     /*
      * try to build a valid creation date/time
      */
@@ -594,6 +611,9 @@ enum mad_flow Kwave::MP3Decoder::fillInput(struct mad_stream *stream)
     // buffer is filled -> process it
     mad_stream_buffer(stream, m_buffer, size);
 
+    // signal the current position
+    emit sourceProcessed(m_source->pos());
+
     return MAD_FLOW_CONTINUE;
 }
 
