@@ -47,10 +47,10 @@ namespace Kwave
         MP3Encoder();
 
         /** Destructor */
-        virtual ~MP3Encoder() Q_DECL_OVERRIDE;
+        ~MP3Encoder() override;
 
         /** Returns a new instance of the encoder */
-        virtual Kwave::Encoder *instance() Q_DECL_OVERRIDE;
+        Kwave::Encoder *instance() override;
 
         /**
          * Encodes a signal into a stream of bytes.
@@ -64,11 +64,11 @@ namespace Kwave
         virtual bool encode(QWidget *widget, Kwave::MultiTrackReader &src,
                             QIODevice &dst,
                             const Kwave::MetaDataList &meta_data)
-                            Q_DECL_OVERRIDE;
+                            override;
 
         /** Returns a list of supported file properties */
         virtual QList<Kwave::FileProperty> supportedProperties()
-                            Q_DECL_OVERRIDE;
+                            override;
 
     private slots:
 
