@@ -27,8 +27,10 @@
 
 #include "MP3EncoderSettings.h"
 
+using namespace Qt::StringLiterals;
+
 /** name of the section in the config file */
-#define MP3_ENCODER_CONFIG_GROUP "MP3_Encoder_Settings"
+#define MP3_ENCODER_CONFIG_GROUP u"MP3_Encoder_Settings"_s
 
 /**
  * load from config file
@@ -59,7 +61,7 @@ static QString sanitized(const QString &in)
     QString str = in.simplified();
 
     for (int i = 0; i < str.length(); i++) {
-        QCharRef c = str[i];
+        QChar c = str.at(i);
         if ( c.isLetterOrNumber() || c.isSpace() ||
              (c == QLatin1Char('-')) || (c == QLatin1Char('%')) ||
              (c == QLatin1Char('=')) || (c == QLatin1Char('.')) ||
