@@ -94,7 +94,7 @@ QStringList *Kwave::NewSignalPlugin::setup(QStringList &previous_params)
         Kwave::NewSignalDialog(
             parentWidget(), m_samples, m_rate, m_bits, m_tracks, m_bytime);
     Q_ASSERT(dialog);
-    if (!dialog) return Q_NULLPTR;
+    if (!dialog) return nullptr;
 
     QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
@@ -114,11 +114,11 @@ QStringList *Kwave::NewSignalPlugin::setup(QStringList &previous_params)
         );
     } else {
         // user pressed "Cancel"
-        if (list) delete list;
-        list = Q_NULLPTR;
+        delete list;
+        list = nullptr;
     }
 
-    if (dialog) delete dialog;
+    delete dialog;
     return list;
 }
 
@@ -126,3 +126,5 @@ QStringList *Kwave::NewSignalPlugin::setup(QStringList &previous_params)
 #include "NewSignalPlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_NewSignalPlugin.cpp"
