@@ -76,9 +76,9 @@ KWAVE_PLUGIN(playback, PlayBackPlugin)
 Kwave::PlayBackPlugin::PlayBackPlugin(QObject *parent,
                                       const QVariantList &args)
     :Kwave::Plugin(parent, args),
-     m_dialog(Q_NULLPTR),
+     m_dialog(nullptr),
      m_playback_controller(manager().playbackController()),
-     m_playback_sink(Q_NULLPTR)
+     m_playback_sink(nullptr)
 {
 }
 
@@ -86,8 +86,8 @@ Kwave::PlayBackPlugin::PlayBackPlugin(QObject *parent,
 Kwave::PlayBackPlugin::~PlayBackPlugin()
 {
     // make sure the dialog is gone
-    if (m_dialog) delete m_dialog;
-    m_dialog = Q_NULLPTR;
+    delete m_dialog;
+    m_dialog = nullptr;
 
     Q_ASSERT(!m_playback_sink);
 }
@@ -158,14 +158,14 @@ void Kwave::PlayBackPlugin::unload()
 //***************************************************************************
 QStringList *Kwave::PlayBackPlugin::setup(QStringList &previous_params)
 {
-    QStringList *result = Q_NULLPTR;
+    QStringList *result = nullptr;
 
     // try to interpret the list of previous parameters, ignore errors
     Kwave::PlayBackParam playback_params =
         interpreteParameters(previous_params);
 
     Q_ASSERT(!m_dialog);
-    if (m_dialog) delete m_dialog;
+    delete m_dialog;
 
     m_dialog = new(std::nothrow) Kwave::PlayBackDialog(
         *this,
@@ -173,14 +173,11 @@ QStringList *Kwave::PlayBackPlugin::setup(QStringList &previous_params)
         playback_params
     );
     Q_ASSERT(m_dialog);
-    if (!m_dialog) return Q_NULLPTR;
+    if (!m_dialog) return nullptr;
 
     connect(m_dialog, SIGNAL(sigTestPlayback()),
             this, SLOT(testPlayBack()));
 
-    // activate the playback method
-    m_dialog->setMethod(playback_params.method);
-
     if ((m_dialog->exec() == QDialog::Accepted) && m_dialog) {
         // get the new parameters and let them take effect
         result = new(std::nothrow) QStringList();
@@ -222,7 +219,7 @@ QStringList *Kwave::PlayBackPlugin::setup(QStringList &previous_params)
     }
 
     delete m_dialog;
-    m_dialog = Q_NULLPTR;
+    m_dialog = nullptr;
 
     return result;
 }
@@ -286,7 +283,7 @@ Kwave::PlayBackDevice *Kwave::PlayBackPlugin::createDevice(
             break;
     }
 
-    return Q_NULLPTR; // nothing found :-(
+    return nullptr; // nothing found :-(
 }
 
 //***************************************************************************
@@ -471,7 +468,7 @@ void Kwave::PlayBackPlugin::testPlayBack()
     // close the playback sink again (here in main thread context)
     m_playback_sink->setInteractive(false);
     delete m_playback_sink;
-    m_playback_sink = Q_NULLPTR;
+    m_playback_sink = nullptr;
 
     // free the progress dialog
     delete progress;
@@ -487,3 +484,5 @@ void Kwave::PlayBackPlugin::testPlayBack()
 #include "PlayBackPlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_PlayBackPlugin.cpp"
