@@ -38,12 +38,12 @@ namespace Kwave
         explicit UndoReverseAction(Kwave::PluginManager &plugin_manager);
 
         /** Destructor */
-        virtual ~UndoReverseAction() Q_DECL_OVERRIDE;
+        ~UndoReverseAction() override;
 
         /**
          * Returns a verbose short description of the action.
          */
-        virtual QString description() Q_DECL_OVERRIDE;
+        QString description() override;
 
         /**
          * Returns the required amount of memory that is needed for storing
@@ -51,13 +51,13 @@ namespace Kwave
          * free memory to be reserved.
          * @note this is the first step (after the constructor)
          */
-        virtual qint64 undoSize() Q_DECL_OVERRIDE;
+        qint64 undoSize() override;
 
         /**
          * Returns the difference of needed memory that is needed for
          * redo.
          */
-        virtual qint64 redoSize() Q_DECL_OVERRIDE;
+        qint64 redoSize() override;
 
         /**
          * Stores the data needed for undo.
@@ -65,7 +65,7 @@ namespace Kwave
          * @note this is the second step, after size() has been called
          * @return true if successful, false if failed (e.g. out of memory)
          */
-        virtual bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
+        bool store(Kwave::SignalManager &manager) override;
 
         /**
          * Takes back an action by creating a new undo action (for further
@@ -78,7 +78,7 @@ namespace Kwave
          *       UndoAction object after undo.
          */
         virtual UndoAction *undo(Kwave::SignalManager &manager, bool with_redo)
-            Q_DECL_OVERRIDE;
+            override;
 
     private:
 
